==> v3.9.tar.gz: privacyguides.org/docs/index.md <==
---
template: overrides/home.en.html
hide:
  - navigation
  - toc
  - feedback
schema:
  - 
    "@context": https://schema.org
    "@type": Organization
    "@id": https://www.privacyguides.org/
    name: Privacy Guides
    url: https://www.privacyguides.org/en/about/
    logo: https://www.privacyguides.org/en/assets/brand/png/square/pg-yellow.png
    sameAs:
      - https://twitter.com/privacy_guides
      - https://github.com/privacyguides
      - https://www.wikidata.org/wiki/Q111710163
      - https://opencollective.com/privacyguides
      - https://www.youtube.com/@privacyguides
      - https://mastodon.neat.computer/@privacyguides
  - 
    "@context": https://schema.org
    "@type": WebSite
    name: Privacy Guides
    url: "https://www.privacyguides.org/"
    sameAs:
      - https://www.wikidata.org/wiki/Q111710163
    potentialAction:
      "@type": SearchAction
      target:
        "@type": EntryPoint
        urlTemplate: "https://www.privacyguides.org/?q={search_term_string}"
      query-input: required name=search_term_string
---
<!-- markdownlint-disable-next-line -->
## Why should I care?

##### “I have nothing to hide. Why should I care about my privacy?”

Much like the right to interracial marriage, woman's suffrage, freedom of speech, and many others, our right to privacy hasn't always been upheld. In several dictatorships, it still isn't. Generations before ours fought for our right to privacy. ==Privacy is a human right, inherent to all of us,== that we are entitled to (without discrimination).

You shouldn't confuse privacy with secrecy. We know what happens in the bathroom, but you still close the door. That's because you want privacy, not secrecy. **Everyone** has something to protect. Privacy is something that makes us human.

[:material-target-account: Common Internet Threats](basics/common-threats.md){ class="md-button md-button--primary" }

## What should I do?

##### First, you need to make a plan

Trying to protect all your data from everyone all the time is impractical, expensive, and exhausting. But don't worry! Security is a process, and, by thinking ahead, you can put together a plan that's right for you. Security isn't just about the tools you use or the software you download. Rather, it begins by understanding the unique threats you face, and how you can mitigate them.

==This process of identifying threats and defining countermeasures is called **threat modeling**==, and it forms the basis of every good security and privacy plan.

[:material-book-outline: Learn More About Threat Modeling](basics/threat-modeling.md){ class="md-button md-button--primary" }

---

## We need you! Here's how to get involved:

[:simple-discourse:](https://discuss.privacyguides.net/){ title="Join our Forum" }
[:simple-mastodon:](https://mastodon.neat.computer/@privacyguides){ rel=me title="Follow us on Mastodon" }
[:material-book-edit:](https://github.com/privacyguides/privacyguides.org){ title="Contribute to this website" }
[:material-translate:](https://matrix.to/#/#pg-i18n:aragon.sh){ title="Help translate this website" }
[:simple-matrix:](https://matrix.to/#/#privacyguides:matrix.org){ title="Chat with us on Matrix" }
[:material-information-outline:](about/index.md){ title="Learn more about us" }
[:material-hand-coin-outline:](about/donate.md){ title="Support the project" }

It's important for a website like Privacy Guides to always stay up-to-date. We need our audience to keep an eye on software updates for the applications listed on our site and follow recent news about providers that we recommend. It's hard to keep up with the fast pace of the internet, but we try our best. If you spot an error, think a provider should not be listed, notice a qualified provider is missing, believe a browser plugin is no longer the best choice, or uncover any other issue, please let us know.

==> 2024.07.28.tar.gz: privacyguides.org/docs/index.md <==
---
meta_title: "Privacy Guides: Your Independent Privacy and Security Resource"
template: home.html
social:
  cards_layout: home
hide:
  - navigation
  - toc
  - feedback
schema:
  -
    "@context": https://schema.org
    "@type": Organization
    "@id": https://www.privacyguides.org/
    name: Privacy Guides
    url: https://www.privacyguides.org/en/about/
    logo: https://www.privacyguides.org/en/assets/brand/logos/png/square/pg-yellow.png
    sameAs:
      - https://twitter.com/privacy_guides
      - https://github.com/privacyguides
      - https://www.wikidata.org/wiki/Q111710163
      - https://opencollective.com/privacyguides
      - https://www.youtube.com/@privacyguides
      - https://mastodon.neat.computer/@privacyguides
  -
    "@context": https://schema.org
    "@type": WebSite
    name: Privacy Guides
    url: "https://www.privacyguides.org/"
    sameAs:
      - https://www.wikidata.org/wiki/Q111710163
    potentialAction:
      "@type": SearchAction
      target:
        "@type": EntryPoint
        urlTemplate: "https://www.privacyguides.org/?q={search_term_string}"
      query-input: required name=search_term_string
---
<!-- markdownlint-disable -->
<div class="grid" markdown>
<div markdown>
## Why should I care?

##### “I have nothing to hide. Why should I care about my privacy?”

Much like the right to interracial marriage, woman's suffrage, freedom of speech, and many others, our right to privacy hasn't always been upheld. In several dictatorships, it still isn't. Generations before ours fought for our right to privacy. ==Privacy is a human right, inherent to all of us,== that we are entitled to (without discrimination).

You shouldn't confuse privacy with secrecy. We know what happens in the bathroom, but you still close the door. That's because you want privacy, not secrecy. **Everyone** has something to protect. Privacy is something that makes us human.

[:material-book-outline: Why Privacy Matters](basics/why-privacy-matters.md){ class="md-button md-button--primary" }
</div>

<div markdown>
## What should I do?

##### First, you need to make a plan

Trying to protect all your data from everyone all the time is impractical, expensive, and exhausting. But don't worry! Security is a process, and, by thinking ahead, you can put together a plan that's right for you. Security isn't just about the tools you use or the software you download. Rather, it begins by understanding the unique threats you face, and how you can mitigate them.

==This process of identifying threats and defining countermeasures is called **threat modeling**==, and it forms the basis of every good security and privacy plan.

[:material-book-outline: Learn More About Threat Modeling](basics/threat-modeling.md){ class="md-button md-button--primary" }
</div>
</div>
